# -*- coding: utf-8 -*-
# Python version: 2/3
#
# Text and Tree loader
# Simon Fraser University
# Jetic Gu
#
#
from __future__ import absolute_import
import os
import sys
import inspect
import unittest
try:
    from tree import load as loadTree
    from txt import load as loadTxt
except ImportError:
    from natlang.format.tree import load as loadTree
    from natlang.format.txt import load as loadTxt
__version__ = "0.3a"


def load(file, linesToLoad=sys.maxsize, verbose=False):
    try:
        contents = loadTree(file, linesToLoad, verbose=verbose)
        contentsTxt = loadTxt(file, linesToLoad)
        if len([f for f in contents if f is not None]) <\
                (len(contentsTxt) / 2):
            return contentsTxt
    except AttributeError:
        return loadTxt(file, linesToLoad)
    return contents


class TestTxtOrTree(unittest.TestCase):
    def testLoadTreeFromFile(self):
        from natlang.format.tree import constructTree, constructTreeFromStr

        def compare(x, y):
            if x is None and y is None:
                return
            anc, fra, val, child, sibl = x.columnFormat()
            ancG, fraG, valG, childG, siblG = y.columnFormat()
            self.assertSequenceEqual(anc, ancG)
            self.assertSequenceEqual(fra, fraG)
            self.assertSequenceEqual(val, valG)
            return

        currentdir = os.path.dirname(
            os.path.abspath(inspect.getfile(inspect.currentframe())))
        parentdir = os.path.dirname(currentdir)
        content = load(parentdir + "/test/sampleTree.txt", verbose=True)
        gContent = loadTree(parentdir + "/test/sampleTree.txt", verbose=True)
        for x, y in zip(content, gContent):
            compare(x, y)
        return

    def testLoadTxtFromFile(self):
        currentdir = os.path.dirname(
            os.path.abspath(inspect.getfile(inspect.currentframe())))
        parentdir = os.path.dirname(currentdir)
        content = load(parentdir + "/test/sampleDepTree.txt", verbose=True)
        gContent = loadTxt(parentdir + "/test/sampleDepTree.txt")
        for x, y in zip(content, gContent):
            self.assertSequenceEqual(x, y)
        return


if __name__ == '__main__':
    if not bool(getattr(sys, 'ps1', sys.flags.interactive)):
        unittest.main()



from __future__ import absolute_import

from natlang import format

from natlang import exporter
from natlang import fileConverter
from natlang import loader

from natlang import version

name = "natlang"



from __future__ import absolute_import

import unittest
from natlang.format import AMR
from natlang.format import pyCode
from natlang.format import semanticFrame
from natlang.format import tree
from natlang.format import txt
from natlang.format import txtFiles
from natlang.format import txtOrTree
from natlang.format import conll


modules = {
    AMR,
    pyCode,
    semanticFrame,
    tree,
    txt,
    txtFiles,
    txtOrTree,
    conll
}


def testSuite():
    loader = unittest.TestLoader()
    suite = unittest.TestSuite()

    # add tests to the test suite
    for module in modules:
        suite.addTests(loader.loadTestsFromModule(module))
    return suite



# -*- coding: utf-8 -*-
# Python version: 2/3
#
# This script transforms a dependency tree loaded with natlang.format.conll
# Simon Fraser University
# Jetic Gu
#
from __future__ import print_function
from __future__ import absolute_import

import os
import sys
import copy
import inspect
import unittest
import progressbar

from natlang.loader import DataLoader
from natlang.format import conll


# Patter specification
# The pattern is a string with tree structure
# Here are some examples
#
#   ( (* nsubj *) | root | (* advmod *) )
#   This matches any tree with a subtree, the root of which has a nsubj as
#   leftChild and an advmod as right child
#
def parseBrackets(pattern):
    result = []
    counter = 0
    pattern = pattern.replace('(', " ( ").replace(')', " ) ")
    pattern = pattern.strip().split()
    if pattern[0] != '(':
        pattern = ['('] + pattern
        pattern = [')'] + pattern
    return closeBrackets(pattern)


def closeBrackets(pattern, startIndex=0):
    entry = []
    counter = 0
    i = startIndex
    while i < len(pattern):
        if pattern[i] == '(':
            counter += 1
            if counter > 1:
                subEntry, i = closeBrackets(pattern, i)
                entry.append(subEntry)
                continue
        elif pattern[i] == ')':
            counter -= 1
            if counter < 0:
                raise ValueError(
                    "natlang.analysis.conllTransformer.closeBrackets: " +
                    "invalid pattern, brackets not closed")
            if counter == 0:
                return entry, i
        else:
            entry.append(pattern[i])
        i += 1
    if counter != 0:
        raise ValueError(
            "natlang.analysis.conllTransformer.closeBrackets: invalid " +
            "pattern, brackets not closed")
    return entry, i


def matchPattern(pattern, node):
    candidates = []

    # Value check
    if not isinstance(pattern, str):
        raise ValueError(
            "natlang.analysis.conllTransformer.matchPattern: pattern must " +
            "be a str")

    if not isinstance(node, conll.Node):
        raise ValueError(
            "natlang.analysis.conllTransformer.node: pattern must be a" +
            "natlang.format.conll.Node instance ")

    # bracket parser
    def parseBrackets(pattern):
        result = []
        counter = 0
        pattern.replace('(', " ( ").replace(')', " ) ")
        pattern = pattern.strip().split()
        return

    return candidates


class TestTree(unittest.TestCase):
    def testParseBracket1(self):
        content, _ = parseBrackets("(closeBrackets(pattern))")
        answer = ["closeBrackets", ["pattern"]]
        self.assertSequenceEqual(content, answer)
        return


if __name__ == '__main__':
    if not bool(getattr(sys, 'ps1', sys.flags.interactive)):
        unittest.main()
